summaryrefslogtreecommitdiff
path: root/Source/Core/VideoCommon/TextureCacheBase.h
diff options
context:
space:
mode:
authorDentomologist <dentomologist@gmail.com>2023-09-01 22:50:48 -0700
committerDentomologist <dentomologist@gmail.com>2023-09-01 22:52:17 -0700
commitd5d3eb5025570e3e62e45d6985f9e34c356ceadd (patch)
tree4f78b7557babf62669cfebaecac2581204a6fe57 /Source/Core/VideoCommon/TextureCacheBase.h
parent5e5887a378db28324a8fc8825f21539525412e12 (diff)
TextureCacheBase: Add m_ prefix to member variables
Diffstat (limited to 'Source/Core/VideoCommon/TextureCacheBase.h')
-rw-r--r--Source/Core/VideoCommon/TextureCacheBase.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/Source/Core/VideoCommon/TextureCacheBase.h b/Source/Core/VideoCommon/TextureCacheBase.h
index 3592535a65..3c942ed8c2 100644
--- a/Source/Core/VideoCommon/TextureCacheBase.h
+++ b/Source/Core/VideoCommon/TextureCacheBase.h
@@ -138,7 +138,7 @@ struct TCacheEntry
u64 id = 0;
u32 content_semaphore = 0; // Counts up
// Indicates that this TCacheEntry has been invalided from textures_by_address
bool invalidated = false;
bool reference_changed = false; // used by xfb to determine when a reference xfb changed
@@ -151,7 +151,7 @@ struct TCacheEntry
// used to delete textures which haven't been used for TEXTURE_KILL_THRESHOLD frames
int frameCount = FRAMECOUNT_INVALID;
// Keep an iterator to the entry in textures_by_hash, so it does not need to be searched when
// removing the cache entry
std::multimap<u64, std::shared_ptr<TCacheEntry>>::iterator textures_by_hash_iter;
@@ -330,8 +330,8 @@ protected:
float gamma, bool clamp_top, bool clamp_bottom,
const std::array<u32, 3>& filter_coefficients);
- alignas(16) u8* temp = nullptr;
- size_t temp_size = 0;
+ alignas(16) u8* m_temp = nullptr;
+ size_t m_temp_size = 0;
private:
using TexAddrCache = std::multimap<u32, RcTcacheEntry>;
@@ -405,20 +405,20 @@ private:
void DoSaveState(PointerWrap& p);
void DoLoadState(PointerWrap& p);
// textures_by_address is the authoritive version of what's actually "in" the texture cache
// but it's possible for invalidated TCache entries to live on elsewhere
- TexAddrCache textures_by_address;
+ TexAddrCache m_textures_by_address;
- // textures_by_hash is an alternative view of the texture cache
- // All textures in here will also be in textures_by_address
- TexHashCache textures_by_hash;
+ // m_textures_by_hash is an alternative view of the texture cache
+ // All textures in here will also be in m_textures_by_address
+ TexHashCache m_textures_by_hash;
- // bound_textures are actually active in the current draw
+ // m_bound_textures are actually active in the current draw
// It's valid for textures to be in here after they've been invalidated
- std::array<RcTcacheEntry, 8> bound_textures{};
+ std::array<RcTcacheEntry, 8> m_bound_textures{};
- TexPool texture_pool;
- u64 last_entry_id = 0;
+ TexPool m_texture_pool;
+ u64 m_last_entry_id = 0;
// Backup configuration values
struct BackupConfig
@@ -437,7 +437,7 @@ private:
bool graphics_mods;
u32 graphics_mod_change_count;
};
- BackupConfig backup_config = {};
+ BackupConfig m_backup_config = {};
// Encoding texture used for EFB copies to RAM.
std::unique_ptr<AbstractTexture> m_efb_encoding_texture;
@@ -138,7 +138,7 @@ struct TCacheEntry
u64 id = 0;
u32 content_semaphore = 0; // Counts up
- // Indicates that this TCacheEntry has been invalided from textures_by_address
+ // Indicates that this TCacheEntry has been invalided from m_textures_by_address
bool invalidated = false;
bool reference_changed = false; // used by xfb to determine when a reference xfb changed
@@ -151,7 +151,7 @@ struct TCacheEntry
// used to delete textures which haven't been used for TEXTURE_KILL_THRESHOLD frames
int frameCount = FRAMECOUNT_INVALID;
- // Keep an iterator to the entry in textures_by_hash, so it does not need to be searched when
+ // Keep an iterator to the entry in m_textures_by_hash, so it does not need to be searched when
// removing the cache entry
std::multimap<u64, std::shared_ptr<TCacheEntry>>::iterator textures_by_hash_iter;
@@ -405,20 +405,20 @@ private:
void DoSaveState(PointerWrap& p);
void DoLoadState(PointerWrap& p);
- // textures_by_address is the authoritive version of what's actually "in" the texture cache
+ // m_textures_by_address is the authoritive version of what's actually "in" the texture cache
// but it's possible for invalidated TCache entries to live on elsewhere